@@ -61,7 +61,7 @@ class CommandsCache(cabc.Mapping):
          name on Windows as a list, conserving the ordering in `PATHEXT`.
          Returns a list as `name` being the only item in it on other platforms."""
         if ON_WINDOWS:
-            pathext = builtins.__xonsh_env__.get('PATHEXT')
+            pathext = builtins.__xonsh_env__.get('PATHEXT', [])
             name = name.upper()
             return [
                 name + ext
@@ -343,6 +343,7 @@ def default_threadable_predictors():
         'clear': predict_false,
         'cls': predict_false,
         'cmd': predict_shell,
+        'curl': predict_true,
         'ex': predict_false,
         'emacsclient': predict_false,
         'fish': predict_shell,
